##  Navigating Between Linked Diagrams
Diagrams can be linked to other diagrams to help you navigate across different levels of detail in your architecture. When you view a diagram, choosing a shape that's linked to another diagram opens that linked diagram.
When you select a linked shape:
  * The linked diagram opens in the same tab.
  * A back arrow appears next to the diagram title. You can use it to return to the previous diagram.
  * Your navigation path is preserved.

![An animation showing navigation between two linked diagrams.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2742c3047a4410148274983e2e34d185_LowRes.gif)
If you're viewing a diagram in a dashboard panel, you can use the Back and Forward arrows to move between linked diagrams. Choose History to show all previously visited diagrams in your current session.
![Dashboard with a bubble chart and a diagram panel showing navigation arrows.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274d59cd7a4410148b1483956181d9e4_LowRes.png)
**Note**
To create links between diagrams, you need edit permissions. For information, see [Linking and Unlinking Fact Sheets to Shapes](https://help.sap.com/docs/leanix/ea/free-draw?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a369c7a4410148ff4e12bcf658e03__linking_and_unlinking_fact_sheets_to_shapes_in_diagrams).
